@@ -140,6 +140,7 @@ struct _CtrlSystem {
     Display *dpy;   /* X display connection */
     Bool has_nv_control;
     Bool has_nvml;
+    void *wayland_output;
 
     CtrlTargetNode *targets[MAX_TARGET_TYPES]; /* Shadows targetTypeTable */
     CtrlTargetNode *physical_screens;
@@ -283,7 +284,15 @@ typedef enum {
 
 #define NV_CTRL_ATTR_NVML_GPU_GRID_LICENSABLE_FEATURES          (NV_CTRL_ATTR_NVML_BASE + 2)
 
-#define NV_CTRL_ATTR_NVML_LAST_ATTRIBUTE (NV_CTRL_ATTR_NVML_GPU_GRID_LICENSABLE_FEATURES)
+#define NV_CTRL_ATTR_NVML_GSP_FIRMWARE_MODE                     (NV_CTRL_ATTR_NVML_BASE + 3)
+
+#define NV_CTRL_ATTR_NVML_GPU_GET_POWER_USAGE                   (NV_CTRL_ATTR_NVML_BASE + 5)
+
+#define NV_CTRL_ATTR_NVML_GPU_MAX_TGP                           (NV_CTRL_ATTR_NVML_BASE + 6)
+
+#define NV_CTRL_ATTR_NVML_GPU_DEFAULT_TGP                       (NV_CTRL_ATTR_NVML_BASE + 7)
+
+#define NV_CTRL_ATTR_NVML_LAST_ATTRIBUTE (NV_CTRL_ATTR_NVML_GPU_DEFAULT_TGP)
 
 #define NV_CTRL_ATTR_LAST_ATTRIBUTE \
         (NV_CTRL_ATTR_NVML_LAST_ATTRIBUTE)
